Alexis' log - Alexis Métaireau

3. # Unbelievable !

   Or completely awesome. Depends the needs.

   a root-relative link to markdown-article a file-relative link to markdown-article

   ## Testing sourcecode directive

       1
       formatter = self.options and VARIANTS[self.options.keys()[0]]

   ## Testing another case

   This will now have a line number in 'custom' since it's the default in pelican.conf, it ...

   read more

   There are comments.

4. # The baz tag

   This article overrides the listening of the articles under the baz tag.

   read more

   There are comments.

« Page 3 / 3

## blogroll

- Biologeek
- Filyb
- Libert-fr
- N1k0
- Tarek Ziadé
- Zubin Mithra

## social

- atom feed
- rss feed
- twitter
- lastfm
- github